@@ -13,7 +13,6 @@ __all__ = [
     "ExpandObjectsThread",
     "SlabThread",
     "TransitionThread",
-    "get_eplus_dirs",
 ]
 
 from archetypal.eplus_interface.basement import BasementThread
@@ -31,4 +30,4 @@ from archetypal.eplus_interface.exceptions import (
 from archetypal.eplus_interface.expand_objects import ExpandObjectsThread
 from archetypal.eplus_interface.slab import SlabThread
 from archetypal.eplus_interface.transition import TransitionThread
-from archetypal.eplus_interface.version import EnergyPlusVersion, get_eplus_dirs
+from archetypal.eplus_interface.version import EnergyPlusVersion
