@@ -11,6 +11,8 @@ from pandas import to_datetime
 from path import Path
 from typing_extensions import Literal
 
+from archetypal.utils import log
+
 _REPORTING_FREQUENCIES = Literal[
     "HVAC System Timestep",
     "Zone Timestep",
@@ -271,9 +273,10 @@ class Sql:
                     variable_or_meter,
                     reporting_frequency,
                 ) not in self.available_outputs:
-                    logging.warning(
+                    log(
                         f"{(variable_or_meter, reporting_frequency)} not "
-                        f"an available output in the Sql file."
+                        f"an available output in the Sql file.",
+                        level=logging.WARNING,
                     )
                 query = f"""
                         SELECT {cols} 
@@ -326,7 +329,7 @@ class Sql:
             # extract all data of the relevant type from ReportData
             rel_indices = tuple(header_rows.index.to_list())
             data = _extract_timeseries(conn, environment_type, header_rows, rel_indices)
-        print(f"collected data for {variable_or_meter}")
+        log(f"collected data for {variable_or_meter}")
         return data
 
     def tabular_data_by_name(
@@ -369,10 +372,11 @@ class Sql:
             except ValueError:
                 # Cannot pivot; return long-form DataFrame
                 pivoted = data
-                logging.warning(
+                log(
                     f"{(report_name, table_name, report_name)} cannot be "
                     f"pivoted as RowName and ColumnName. The long-form "
-                    f"DataFrame has been returned."
+                    f"DataFrame has been returned.",
+                    level=logging.WARNING,
                 )
             pivoted = pivoted.apply(pd.to_numeric, errors="ignore")
         return pivoted
