@@ -128,16 +128,12 @@ resource_package = archetypal.__name__  # Could be any module/package name
 
 from energy_pandas.units import unit_registry
 
-unit_registry.define("m3 = 1 * meter ** 3 = m³")
-unit_registry.define(
-    "degree_Celsius = kelvin; offset: 273.15 = °C = C = celsius = degC = degreeC"
+additional_units = (
+    "Dimensionless = dimensionless = Fraction = fraction",
+    "@alias degC = Temperature = temperature",
 )
-unit_registry.define(
-    "degree_Fahrenheit = 5 / 9 * kelvin; offset: 233.15 + 200 / 9 = "
-    "°F = F = fahrenheit = degF = degreeF"
-)
-unit_registry.define("ach = dimensionless")  # Air Changes per Hour
-unit_registry.define("acr = 1 / hour")  # Air change rate
+for unit in additional_units:
+    unit_registry.define(unit)
 
 
 class ZoneWeight(object):
@@ -164,8 +160,4 @@ class ZoneWeight(object):
 zone_weight = ZoneWeight(n=0)
 
 # Latest version of EnergyPlus compatible with archetypal looks for ENERGYPLUS_VERSION in os.environ
-ep_version = (
-    os.getenv("ENERGYPLUS_VERSION").replace("-", ".")
-    if os.getenv("ENERGYPLUS_VERSION")
-    else "9-2-0"  # default if not found
-)
+ep_version = os.getenv("ENERGYPLUS_VERSION", "9-2-0")
